DROP VIEW IF EXISTS sod_case_action_v;
DROP VIEW IF EXISTS spermission_v;
DROP VIEW IF EXISTS suser_name_v;
DROP VIEW IF EXISTS adhoc_suser_v;
DROP VIEW IF EXISTS suser_spermission_cert_risk_v;
DROP VIEW IF EXISTS adhoc_apps_spermissions_v;
DROP VIEW IF EXISTS review_item_status_v;
DROP VIEW IF EXISTS adhoc_apps_spermissions_all_v;
DROP VIEW IF EXISTS access_review_details_v;
DROP VIEW IF EXISTS shared_accounts_v;

CREATE VIEW suser_name_v AS 
  SELECT 
    unique_user_id, 
    display_name 
  FROM suser 
  WHERE effective = true and deleted = false;

CREATE VIEW spermission_v AS 
 SELECT DISTINCT spermission.id,
    spermission.account_grant,
    spermission.assignable,
    spermission.authoritative,
    spermission.bound_by_id,
    spermission.boundable,
    spermission.cost,
    spermission.deleted,
    spermission.description,
    spermission.display_name,
    spermission.driver_id,
    spermission.effective,
    spermission.exclude_from_catalog,
    spermission.is_curated,
    spermission.logical_id,
    spermission.merged,
    spermission.name,
    spermission.not_reviewable,
    spermission.permission_id,
    spermission.prov_attribute,
    spermission.prov_by_unique_permission_id,
    spermission.prov_native_value,
    spermission.prov_unique_driver_id,
    spermission.provisionable,
    spermission.risk,
    spermission.type,
    spermission.unique_bound_by_id,
    spermission.unique_permission_id,
    spermission.value,
    spermission.value_type,
    spermission.application,
    spermission.base_application,
    spermission.collected_entity,
    spermission.data_collection,
    spermission.effective_entity,
    spermission.sversion,
    spermission.auto_generated,
    spermission.prov_unique_permission_id,
    auth_by.brole_name AS authorized_by,
    string_agg(su.display_name::text, ' | '::text) AS perm_owner_name
   FROM spermission
     LEFT JOIN ( SELECT brole.brole_name,
            brole.unique_item_id
           FROM ( SELECT br_incl_item.business_role_id,
                    br_incl_item.unique_item_id,
                    ( SELECT DISTINCT brole_1.name
                           FROM business_role brole_1
                          WHERE br_incl_item.business_role_id = brole_1.id AND brole_1.approval_state::text = 'PUBLISHED'::text) AS brole_name
                   FROM business_role_incl_item br_incl_item) brole,
            spermission spermission_1
          WHERE brole.unique_item_id::text = spermission_1.unique_permission_id::text AND brole.brole_name IS NOT NULL) auth_by ON auth_by.unique_item_id::text = spermission.unique_permission_id::text
     LEFT JOIN resolved_spermission_owner rso ON rso.permission = spermission.id
     LEFT JOIN suser_name_v su ON su.unique_user_id::text = rso.owner_unique_id::text
  WHERE spermission.deleted = false AND spermission.effective = true
  GROUP BY spermission.id, spermission.account_grant, spermission.assignable, spermission.authoritative, spermission.bound_by_id, spermission.boundable, spermission.cost, spermission.deleted, spermission.description, spermission.display_name, spermission.driver_id, spermission.effective, spermission.exclude_from_catalog, spermission.is_curated, spermission.logical_id, spermission.merged, spermission.name, spermission.not_reviewable, spermission.permission_id, spermission.prov_attribute, spermission.prov_by_unique_permission_id, spermission.prov_native_value, spermission.prov_unique_driver_id, spermission.provisionable, spermission.risk, spermission.type, spermission.unique_bound_by_id, spermission.unique_permission_id, spermission.value, spermission.value_type, spermission.application, spermission.base_application, spermission.collected_entity, spermission.data_collection, spermission.effective_entity, spermission.sversion, spermission.auto_generated, spermission.prov_unique_permission_id, auth_by.brole_name
  ORDER BY spermission.name;

CREATE VIEW sod_case_action_v AS 
 SELECT sod_case_info.id AS case_number,
    sod_case_info.state AS case_status,
    sod_case_info.policy,
    sod_case_info.policy_name,
    sod_policy.deleted AS policy_status,
    sod_case_info.violator_is_user,
    sod_case_info.violator_name,
    sod_case_info.violator_title,
    sod_case_action.id AS action_id,
    sod_case_action.action,
    sod_case_action.action_comment,
    sod_case_action.action_time,
    suser.display_name AS performed_by,
    sod_case_action.control_period,
        CASE
            WHEN sod_case_action.control_period IS NOT NULL THEN sod_case_action.action_time + (( SELECT (sod_case_action.control_period || ' days'::text)::interval AS "interval"))
            ELSE NULL::timestamp with time zone
        END AS approval_expiration,
    sod_removal_item.type AS item_type,
        CASE
            WHEN sod_removal_item.type::text = 'PERMISSION'::text THEN spermission_v.name
            ELSE role_policy.name
        END AS item_name,
    count(cri.id) AS total_number,
    ( SELECT count(*) AS count
           FROM sod_case_action sca2
             LEFT JOIN change_request_item cri_1 ON cri_1.sod_case_action = sod_case_action.id
             LEFT JOIN change_item_action cia ON cri_1.latest_action = cia.id
          WHERE sca2.id = sod_case_action.id AND cia.change_item_status::text = 'PENDING'::text AND cri_1.provisioning_type::text = 'MANUAL'::text) AS pending_manual_number,
    ( SELECT count(*) AS count
           FROM sod_case_action sca2
             LEFT JOIN change_request_item cri_1 ON cri_1.sod_case_action = sod_case_action.id
             LEFT JOIN change_item_action cia ON cri_1.latest_action = cia.id
          WHERE sca2.id = sod_case_action.id AND cia.change_item_status::text = 'PENDING'::text AND cri_1.provisioning_type::text = 'IDENTITY_MANAGER'::text) AS pending_idm_number,
    ( SELECT count(*) AS count
           FROM sod_case_action sca2
             LEFT JOIN change_request_item cri_1 ON cri_1.sod_case_action = sod_case_action.id
             LEFT JOIN change_item_action cia ON cri_1.latest_action = cia.id
          WHERE sca2.id = sod_case_action.id AND cia.change_item_status::text = 'PENDING'::text AND cri_1.provisioning_type::text = 'EXTERNAL_WORKFLOW'::text) AS pending_ext_number,
    ( SELECT count(*) AS count
           FROM sod_case_action sca2
             LEFT JOIN change_request_item cri_1 ON cri_1.sod_case_action = sod_case_action.id
             LEFT JOIN change_item_action cia ON cri_1.latest_action = cia.id
          WHERE sca2.id = sod_case_action.id AND cia.change_item_status::text = 'INITIALIZED'::text) AS initialized_number,
    ( SELECT count(*) AS count
           FROM sod_case_action sca2
             LEFT JOIN change_request_item cri_1 ON cri_1.sod_case_action = sod_case_action.id
             LEFT JOIN change_item_action cia ON cri_1.latest_action = cia.id
          WHERE sca2.id = sod_case_action.id AND cia.change_item_status::text = 'VERIFIED'::text) AS verified_number,
    ( SELECT count(*) AS count
           FROM sod_case_action sca2
             LEFT JOIN change_request_item cri_1 ON cri_1.sod_case_action = sod_case_action.id
             LEFT JOIN change_item_action cia ON cri_1.latest_action = cia.id
          WHERE sca2.id = sod_case_action.id AND cia.change_item_status::text = 'REFUSED'::text) AS refused_number,
    ( SELECT count(*) AS count
           FROM sod_case_action sca2
             LEFT JOIN change_request_item cri_1 ON cri_1.sod_case_action = sod_case_action.id
             LEFT JOIN change_item_action cia ON cri_1.latest_action = cia.id
          WHERE sca2.id = sod_case_action.id AND cia.change_item_status::text = 'VERIFICATION_IGNORED'::text) AS verification_ignored_number,
    ( SELECT count(*) AS count
           FROM sod_case_action sca2
             LEFT JOIN change_request_item cri_1 ON cri_1.sod_case_action = sod_case_action.id
             LEFT JOIN change_item_action cia ON cri_1.latest_action = cia.id
          WHERE sca2.id = sod_case_action.id AND cia.change_item_status::text = 'NOT_VERIFIED'::text) AS not_verified_number,
    ( SELECT count(*) AS count
           FROM sod_case_action sca2
             LEFT JOIN change_request_item cri_1 ON cri_1.sod_case_action = sod_case_action.id
             LEFT JOIN change_item_action cia ON cri_1.latest_action = cia.id
          WHERE sca2.id = sod_case_action.id AND cia.change_item_status::text = 'VERIFICATION_TIMEOUT'::text) AS verification_timeout_number,
    ( SELECT count(*) AS count
           FROM sod_case_action sca2
             LEFT JOIN change_request_item cri_1 ON cri_1.sod_case_action = sod_case_action.id
             LEFT JOIN change_item_action cia ON cri_1.latest_action = cia.id
          WHERE sca2.id = sod_case_action.id AND cia.change_item_status::text = 'ERROR'::text) AS error_number,
    ( SELECT count(*) AS count
           FROM sod_case_action sca2
             LEFT JOIN change_request_item cri_1 ON cri_1.sod_case_action = sod_case_action.id
             LEFT JOIN change_item_action cia ON cri_1.latest_action = cia.id
          WHERE sca2.id = sod_case_action.id AND cia.change_item_status::text = 'COMPLETED'::text AND cri_1.provisioning_type::text = 'MANUAL'::text) AS completed_manual_number,
    ( SELECT count(*) AS count
           FROM sod_case_action sca2
             LEFT JOIN change_request_item cri_1 ON cri_1.sod_case_action = sod_case_action.id
             LEFT JOIN change_item_action cia ON cri_1.latest_action = cia.id
          WHERE sca2.id = sod_case_action.id AND cia.change_item_status::text = 'COMPLETED'::text AND cri_1.provisioning_type::text = 'IDENTITY_MANAGER'::text) AS completed_idm_number,
    ( SELECT count(*) AS count
           FROM sod_case_action sca2
             LEFT JOIN change_request_item cri_1 ON cri_1.sod_case_action = sod_case_action.id
             LEFT JOIN change_item_action cia ON cri_1.latest_action = cia.id
          WHERE sca2.id = sod_case_action.id AND cia.change_item_status::text = 'COMPLETED'::text AND cri_1.provisioning_type::text = 'EXTERNAL_WORKFLOW'::text) AS completed_ext_number,
    ( SELECT count(*) AS count
           FROM sod_case_action sca2
             LEFT JOIN change_request_item cri_1 ON cri_1.sod_case_action = sod_case_action.id
             LEFT JOIN change_item_action cia ON cri_1.latest_action = cia.id
          WHERE sca2.id = sod_case_action.id AND cia.change_item_status::text = 'IN_PROGRESS'::text) AS in_progress_number
   FROM sod_case_info
     JOIN sod_policy ON sod_policy.id = sod_case_info.policy
     JOIN sod_case_action ON sod_case_action.sod_case = sod_case_info.id
     LEFT JOIN sod_removal_item ON sod_removal_item.sod_case_action = sod_case_action.id
     LEFT JOIN spermission_v ON spermission_v.unique_permission_id::text = sod_removal_item.unique_id::text
     LEFT JOIN role_policy ON role_policy.unique_policy_id::text = sod_removal_item.unique_id::text AND role_policy.deleted = false
     LEFT JOIN suser ON sod_case_action.performed_by::text = suser.unique_user_id::text AND suser.deleted = false AND suser.effective = true
     LEFT JOIN change_request_item cri ON cri.sod_case_action = sod_case_action.id
  GROUP BY sod_case_info.id, sod_case_info.state, sod_case_info.policy, sod_case_info.policy_name, sod_policy.deleted, sod_case_info.violator_is_user, sod_case_info.violator_name, sod_case_info.violator_title, sod_case_action.id, sod_case_action.action, sod_case_action.action_comment, sod_case_action.action_time, suser.display_name, sod_case_action.control_period, spermission_v.name, role_policy.name, sod_removal_item.type
  ORDER BY sod_case_info.policy_name, sod_case_info.policy, sod_case_info.violator_name, sod_case_action.action_time;

CREATE VIEW shared_accounts_v AS 
 SELECT acct.id,
    acct.unique_account_id,
    acct.name,
    acct.collected_entity,
    acct.effective_entity,
    acct.sversion AS saccount_sversion,
    saccu.suser,
    saccu.sversion AS saccount_user_sversion,
    suser.display_name
   FROM saccount acct
     LEFT JOIN saccount_user saccu ON acct.collected_entity = saccu.saccount
     LEFT JOIN ( SELECT max(saccu2.sversion) AS max_sversion
           FROM saccount_user saccu2) version ON version.max_sversion = saccu.sversion
     LEFT JOIN suser suser ON suser.id = saccu.suser
  WHERE acct.relation_to_user_type::text = 'SHARED'::text AND saccu.effective = false AND acct.virtual = false AND acct.effective = true
  ORDER BY acct.name, suser.display_name;

CREATE VIEW access_review_details_v AS 
 SELECT DISTINCT item.id AS review_item_id,
    item.last_override_action_id AS last_override_action,
    instance.id AS review_instance_id,
    instance.status AS review_status,
    instance.start_date,
    instance.end_date,
    instance.valid_to_date,
    instance.item_count,
    multi_owner.review_owners,
    multi_reviewer.reviewer_ids AS reviewer_id,
        CASE
            WHEN item.final_cert_by_unique_user_id IS NOT NULL THEN final_reviewer.display_name::text
            ELSE multi_reviewer.reviewers
        END AS reviewer_display_name,
    reassigned_by_history.reviewers AS reassigned_by_user_disp_name,
    reassigned_from_history.reviewers AS reassigned_from_user_disp_name,
    reassigned_by_history.reassigned_date,
    defn.name AS review_name,
    substr(defn.description, 0, 4000) AS description,
    defn.review_type,
    defn.next_schedule_date,
        CASE
            WHEN item.item_type::text = 'ACCOUNT'::text AND usr.id IS NULL THEN shacc.suser
            ELSE usr.id
        END AS user_id,
        CASE
            WHEN item.item_type::text = 'ACCOUNT'::text AND usr.display_name IS NULL THEN shacc.display_name::text
            ELSE usr.display_name::text
        END AS user_display_name,
    action.action AS reviewer_action,
    action.review_order,
    action.reviewer_comment,
    perm.id AS permission_id,
    perm.name AS permission_name,
    acct.id AS account_id,
    acct.account_id AS account_native_id,
    acct.name AS account_name,
    acct.relation_to_user_type AS account_relation,
    app.id AS application_id,
    app_ds.name::text AS application_name,
    item.final_decision,
    item.final_decision_time,
    role.id AS role_id,
    role.name AS role_name,
    item.item_type,
    brole.name AS brole_name,
    action.fulfillment_instructions,
    esc_reviewer.display_name
   FROM review_item item
     JOIN review_instance instance ON item.review_instance_id = instance.id
     JOIN review_definition defn ON instance.review_definition = defn.id
     LEFT JOIN suser usr ON usr.unique_user_id::text = item.unique_user_id::text AND usr.effective = true
     LEFT JOIN spermission perm ON perm.unique_permission_id::text = item.unique_permission_id::text AND perm.effective = true
     LEFT JOIN saccount acct ON acct.unique_account_id::text = item.unique_account_id::text AND acct.effective = true
     LEFT JOIN application app ON app.id =
        CASE
            WHEN perm.id IS NULL THEN acct.application
            ELSE perm.application
        END
     LEFT JOIN business_role brole ON brole.id = item.business_role_id
     LEFT JOIN role_policy role ON role.id = item.role_id
     LEFT JOIN data_source app_ds ON app_ds.id = app.id
     LEFT JOIN review_item_action action ON action.review_item_id = item.id AND action.action::text <> 'REASSIGNED'::text
     LEFT JOIN reviewer_instance inst2 ON instance.id = inst2.review_instance_id AND inst2.type::text = 'RO'::text
     LEFT JOIN reviewer_instance inst3 ON instance.id = inst3.review_instance_id
     LEFT JOIN ( SELECT DISTINCT item_1.id AS item_id,
            string_agg(multi_reviewers.id::text, ' | '::text ORDER BY multi_reviewers.id) AS reviewer_ids,
            string_agg(multi_reviewers.unique_user_id::text, ' | '::text ORDER BY multi_reviewers.unique_user_id) AS reviewer_unique_ids,
            string_agg(multi_reviewers.display_name::text, ' | '::text ORDER BY multi_reviewers.display_name) AS reviewers
           FROM review_item item_1
             LEFT JOIN reviewer_user_instance rrui ON rrui.reviewer_instance_id = item_1.curr_reviewer_instance_id
             LEFT JOIN suser multi_reviewers ON rrui.unique_user_id::text = multi_reviewers.unique_user_id::text AND multi_reviewers.effective = true
          GROUP BY item_1.id) multi_reviewer ON multi_reviewer.item_id = item.id
     LEFT JOIN suser final_reviewer ON item.final_cert_by_unique_user_id::text = final_reviewer.unique_user_id::text AND final_reviewer.effective = true
     LEFT JOIN suser acting_reviewer ON action.acted_by_user_unique_id::text = acting_reviewer.unique_user_id::text AND acting_reviewer.effective = true
     LEFT JOIN review_item_action reassigned ON reassigned.review_item_id = item.id AND reassigned.action::text = 'REASSIGNED'::text AND reassigned.reassigned_to_user_unique_id::text ~~ (('%'::text || multi_reviewer.reviewer_unique_ids) || '%'::text)
     LEFT JOIN suser curr_reviewer ON curr_reviewer.unique_user_id::text ~~ (('%'::text || multi_reviewer.reviewer_unique_ids) || '%'::text) AND curr_reviewer.effective = true
     LEFT JOIN ( SELECT DISTINCT ria.review_item_id,
            string_agg(usr_1.display_name::text, ' | '::text ORDER BY ria.assigned) AS reviewers
           FROM review_item_action ria
             LEFT JOIN reviewer_instance ri ON ri.id = ria.reviewer_instance_id
             LEFT JOIN suser usr_1 ON ri.single_reviewer_unique_id::text = usr_1.unique_user_id::text AND usr_1.effective = true
          WHERE ria.action::text = 'REASSIGNED'::text
          GROUP BY ria.review_item_id) reassigned_from_history ON reassigned_from_history.review_item_id = item.id
     LEFT JOIN ( SELECT DISTINCT ria.review_item_id,
            string_agg(usr_1.display_name::text, ' | '::text ORDER BY ria.assigned) AS reviewers,
            string_agg(to_char(ria.assigned, 'YYYY-MM-DD HH24:MI:SS'::text), ' | '::text ORDER BY ria.assigned) AS reassigned_date
           FROM review_item_action ria
             LEFT JOIN suser usr_1 ON ria.reassigned_by_user_unique_id::text = usr_1.unique_user_id::text AND usr_1.effective = true
          WHERE ria.action::text = 'REASSIGNED'::text
          GROUP BY ria.review_item_id) reassigned_by_history ON reassigned_by_history.review_item_id = item.id
     LEFT JOIN shared_accounts_v shacc ON shacc.unique_account_id::text = acct.unique_account_id::text
     LEFT JOIN ( SELECT DISTINCT defn_1.name AS review_name,
            ri.id AS rid,
            string_agg(s.display_name::text, ' | '::text ORDER BY s.display_name) AS review_owners
           FROM review_instance ri
             JOIN review_definition defn_1 ON ri.review_definition = defn_1.id
             LEFT JOIN reviewer_instance rev_owner ON ri.id = rev_owner.review_instance_id AND rev_owner.type::text = 'RO'::text
             LEFT JOIN reviewer_user_instance rui ON rui.reviewer_instance_id = rev_owner.id
             LEFT JOIN suser s ON rui.unique_user_id::text = s.unique_user_id::text AND s.effective = true
          GROUP BY defn_1.name, ri.id) multi_owner ON multi_owner.rid = item.review_instance_id
     LEFT JOIN ( SELECT esc_reviewers.review_instance_id,
            string_agg(esc_reviewers.display_name::text, ' | '::text) AS display_name
           FROM ( SELECT DISTINCT u.display_name,
                    rri.review_instance_id
                   FROM review_item ri
                     JOIN reviewer_instance rri ON ri.curr_reviewer_instance_id = rri.id AND rri.type::text = 'EO'::text
                     JOIN reviewer_user_instance rriu ON rriu.reviewer_instance_id = rri.id
                     JOIN suser u ON u.unique_user_id::text = rriu.unique_user_id::text AND u.effective = true) esc_reviewers
          GROUP BY esc_reviewers.review_instance_id) esc_reviewer ON esc_reviewer.review_instance_id = item.review_instance_id
  WHERE defn.deleted = false AND (acting_reviewer.unique_user_id::text ~~ (('%'::text || multi_reviewer.reviewer_unique_ids) || '%'::text) OR acting_reviewer.unique_user_id IS NULL AND action.review_order = (( SELECT DISTINCT min(act.review_order) AS min
           FROM review_item_action act
          WHERE (act.action::text = 'PENDING'::text OR act.action::text = 'ESCALATE'::text) AND act.review_item_id = item.id)) OR acting_reviewer.unique_user_id IS NOT NULL AND action.shared_queue = true) AND (action.action::text <> 'PENDING'::text OR item.final_decision IS NULL)
  ORDER BY item.id, action.review_order;

CREATE VIEW review_item_status_v AS 
  SELECT DISTINCT
    item.id review_item_id,
    instance.id review_instance_id,
    instance.status review_status,
    instance.start_date,
    instance.end_date,
    instance.item_count,
    CASE
        WHEN item_type = 'ACCOUNT' AND usr.id IS NULL THEN shacc.suser  
        ELSE usr.id
    END user_id,
    CASE
        WHEN item_type = 'ACCOUNT' AND usr.display_name IS NULL THEN shacc.display_name
        ELSE usr.display_name
    END user_display_name,
    perm.id permission_id,
    perm.name permission_name
   FROM review_item item
     JOIN review_instance instance ON item.review_instance_id = instance.id
     LEFT JOIN suser usr ON usr.unique_user_id = item.unique_user_id AND usr.effective = TRUE
     LEFT JOIN spermission perm ON perm.unique_permission_id = item.unique_permission_id AND perm.effective = TRUE
     LEFT JOIN saccount acct ON acct.unique_account_id = item.unique_account_id AND acct.effective = TRUE
     LEFT JOIN shared_accounts_v shacc ON shacc.unique_account_id = acct.unique_account_id
   WHERE instance.status = 'CERTIFIED' OR instance.status = 'CERTIFYING' OR instance.status = 'AUDIT_APPROVAL'
   ORDER BY item.id;

 CREATE VIEW adhoc_apps_spermissions_v AS 
 SELECT suser_account_permission.suser,
    suser_account_permission.saccount,
    data_source.id AS application_id,
    data_source.name AS application_name,
    data_source.description AS application_description,
    application.risk AS application_risk,
    spermission.id AS permission_id,
    spermission.name AS permission_name,
    spermission.description AS permission_description,
    spermission.risk AS permission_risk,
    spermission.type AS permission_type,
    max(review_instance.end_date) AS last_certification,
        CASE
            WHEN max(review_instance.end_date) IS NOT NULL THEN true
            ELSE false
        END AS is_certified,
        CASE
            WHEN certified.review_status::text <> 'CERTIFIED'::text AND certified.user_id IS NOT NULL THEN true
            ELSE false
        END AS certification_pending
   FROM suser_account_permission
     LEFT JOIN spermission ON suser_account_permission.spermission = spermission.id
     LEFT JOIN application ON spermission.application = application.id
     LEFT JOIN data_source ON application.id = data_source.id
     LEFT JOIN review_item_status_v certified ON suser_account_permission.suser = certified.user_id AND spermission.id = certified.permission_id
     LEFT JOIN review_instance ON certified.review_instance_id = review_instance.id
  WHERE spermission.deleted = false AND spermission.effective = true AND data_source.data_source_type::text = 'APPLICATION'::text AND data_source.deleted = false
  GROUP BY suser_account_permission.suser, suser_account_permission.saccount, data_source.id, data_source.name, data_source.description, application.risk, spermission.id, spermission.name, spermission.description, spermission.risk, spermission.type, certified.review_status, certified.user_id;

CREATE VIEW suser_spermission_cert_risk_v AS 
 SELECT DISTINCT suser.id AS suser_id,
    ( SELECT count(spermissions_1.suser) AS count
           FROM adhoc_apps_spermissions_v spermissions_1
          WHERE spermissions_1.suser = suser.id AND spermissions_1.last_certification IS NOT NULL) AS certification_count,
        CASE
            WHEN spermissions.is_certified IS NULL THEN false
            ELSE spermissions.is_certified
        END AS is_certified,
        CASE
            WHEN spermissions.certification_pending IS NULL THEN false
            ELSE spermissions.certification_pending
        END AS certification_pending,
        CASE
            WHEN sum(spermissions.permission_risk) IS NULL THEN 0::numeric
            ELSE sum(spermissions.permission_risk)
        END AS aggregate_permission_risk
   FROM suser
     LEFT JOIN adhoc_apps_spermissions_v spermissions ON spermissions.suser = suser.id
  WHERE suser.deleted = false AND suser.effective = true
  GROUP BY suser.id, spermissions.is_certified, spermissions.certification_pending;

CREATE VIEW adhoc_suser_v AS 
 SELECT suser.id,
    suser.deleted,
    suser.department,
    suser.display_description,
    suser.display_name,
    suser.dn,
    suser.effective,
    suser.employee_status,
    suser.employee_type,
    suser.first_name,
    suser.full_name,
    suser.guid,
    suser.home_phone,
    suser.idm_dn,
    suser.idm_tree_name,
    suser.is_curated,
    suser.job_code,
    suser.job_title,
    suser.last_name,
    suser.location,
    suser.merged,
    suser.middle_name,
    suser.office_phone,
    suser.other_phone,
    suser.preferred_locale,
    suser.provisioning_id,
    suser.secondary_supervisor_id,
    suser.supervisor_attr_key,
    suser.supervisor_id,
    suser.supervisor_unique_id,
    suser.unique_user_id,
    suser.user_id,
    suser.business_unit,
    suser.collected_entity,
    suser.effective_entity,
    suser.identity_source,
    suser.sversion,
    suser.workforce_id,
    suser_email.email,
    suser.risk,
    cert_risk.certification_count,
    cert_risk.is_certified,
    cert_risk.certification_pending,
    cert_risk.aggregate_permission_risk,
    string_agg(perm.name::text, ' | '::text) AS all_permissions,
    brole.name AS business_role,
    brole.description AS brole_description,
    brole.risk AS brole_risk,
    brole.update_time AS brole_update_time
   FROM suser
     LEFT JOIN suser_email ON suser.id = suser_email.suser
     LEFT JOIN spermission perm ON (EXISTS ( SELECT suser_account_permission.suser
           FROM suser_account_permission
          WHERE suser.id = suser_account_permission.suser)) AND perm.deleted = false AND perm.effective = true
     LEFT JOIN suser_spermission_cert_risk_v cert_risk ON suser.id = cert_risk.suser_id
     LEFT JOIN business_role brole ON (EXISTS ( SELECT br_memb.business_role_id
           FROM business_role_incl_memb br_memb
          WHERE suser.unique_user_id::text = br_memb.unique_member_id::text AND br_memb.is_user = true AND br_memb.business_role_id = brole.id))
  WHERE suser.deleted = false AND suser.effective = true
  GROUP BY suser.id, suser.deleted, suser.department, suser.display_description, brole.name, brole.description, brole.risk, brole.update_time, suser.display_name, suser.dn, suser.effective, suser.employee_status, suser.employee_type, suser.first_name, suser.full_name, suser.guid, suser.home_phone, suser.idm_dn, suser.idm_tree_name, suser.is_curated, suser.job_code, suser.job_title, suser.last_name, suser.location, suser.merged, suser.middle_name, suser.office_phone, suser.other_phone, suser.preferred_locale, suser.provisioning_id, suser.secondary_supervisor_id, suser.supervisor_attr_key, suser.supervisor_id, suser.supervisor_unique_id, suser.unique_user_id, suser.user_id, suser.business_unit, suser.collected_entity, suser.effective_entity, suser.identity_source, suser.sversion, suser.workforce_id, suser_email.email, cert_risk.certification_count, cert_risk.is_certified, cert_risk.certification_pending, cert_risk.aggregate_permission_risk;

ALTER TABLE suser_name_v
  OWNER TO igops;
GRANT ALL ON TABLE suser_name_v TO igops;
GRANT SELECT ON TABLE suser_name_v TO ig_report_role;

 ALTER TABLE spermission_v
   OWNER TO igops;
 GRANT ALL ON TABLE spermission_v TO igops;
 GRANT SELECT ON TABLE spermission_v TO ig_report_role;

 ALTER TABLE sod_case_action_v
  OWNER TO igops;
GRANT ALL ON TABLE sod_case_action_v TO igops;
GRANT SELECT ON TABLE sod_case_action_v TO ig_report_role;

ALTER TABLE shared_accounts_v
  OWNER TO igops;
GRANT ALL ON TABLE shared_accounts_v TO igops;
GRANT SELECT ON TABLE shared_accounts_v TO ig_report_role;

ALTER TABLE access_review_details_v
  OWNER TO igops;
GRANT ALL ON TABLE access_review_details_v TO igops;
GRANT SELECT ON TABLE access_review_details_v TO ig_report_role;

ALTER TABLE review_item_status_v
  OWNER TO igops;
GRANT ALL ON TABLE review_item_status_v TO igops;
GRANT SELECT ON TABLE review_item_status_v TO ig_report_role;

ALTER TABLE adhoc_apps_spermissions_v
  OWNER TO igops;
GRANT ALL ON TABLE adhoc_apps_spermissions_v TO igops;
GRANT SELECT ON TABLE adhoc_apps_spermissions_v TO ig_report_role;

ALTER TABLE suser_spermission_cert_risk_v
  OWNER TO igops;
GRANT ALL ON TABLE suser_spermission_cert_risk_v TO igops;
GRANT SELECT ON TABLE suser_spermission_cert_risk_v TO ig_report_role;

ALTER TABLE adhoc_suser_v
  OWNER TO igops;
GRANT ALL ON TABLE adhoc_suser_v TO igops;
GRANT SELECT ON TABLE adhoc_suser_v TO ig_report_role;